@@ -12,7 +12,7 @@
 #' `git_add()` to start tracking new files.
 #'
 #' `git_log()` shows the most recent commits and `git_ls()` lists all the files
-#' that are being tracked in the repository.
+#' that are being tracked in the repository. `git_stat_files()`
 #'
 #' @export
 #' @rdname git_commit
@@ -181,11 +181,23 @@ git_ls <- function(repo = '.'){
 #' @useDynLib gert R_git_commit_log
 #' @param ref revision string with a branch/tag/commit value
 #' @param max lookup at most latest n parent commits
-git_log <- function(ref = "HEAD", max = 100, repo = "."){
+#' @param after date or timestamp: only include commits starting this date
+git_log <- function(ref = "HEAD", max = 100, after = NULL, repo = "."){
   repo <- git_open(repo)
   ref <- as.character(ref)
   max <- as.integer(max)
-  .Call(R_git_commit_log, repo, ref, max)
+  if(length(after))
+    after <- as.POSIXct(after)
+  .Call(R_git_commit_log, repo, ref, max, after)
+}
+
+#' @export
+#' @rdname git_commit
+#' @useDynLib gert R_git_stat_files
+git_stat_files <- function(files, ref = "HEAD", repo = '.'){
+  repo <- git_open(repo)
+  files <- as.character(files)
+  .Call(R_git_stat_files, repo, files, ref)
 }
 
 assert_string <- function(x){
