@@ -4,6 +4,10 @@
 #include <R_ext/Visibility.h>
 #include <git2.h>
 
+#ifdef _WIN32
+#include <sys/stat.h>
+#endif
+
 /* FIXME:
  Check these declarations against the C/Fortran source code.
  */
@@ -23,7 +27,7 @@ extern SEXP R_git_commit_create(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_git_commit_descendant(SEXP, SEXP, SEXP);
 extern SEXP R_git_commit_id(SEXP, SEXP);
 extern SEXP R_git_commit_info(SEXP, SEXP);
-extern SEXP R_git_commit_log(SEXP, SEXP, SEXP);
+extern SEXP R_git_commit_log(SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_git_config_list(SEXP);
 extern SEXP R_git_config_set(SEXP, SEXP, SEXP);
 extern SEXP R_git_conflict_list(SEXP);
@@ -95,7 +99,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"R_git_commit_descendant",   (DL_FUNC) &R_git_commit_descendant,   3},
   {"R_git_commit_id",           (DL_FUNC) &R_git_commit_id,           2},
   {"R_git_commit_info",         (DL_FUNC) &R_git_commit_info,         2},
-  {"R_git_commit_log",          (DL_FUNC) &R_git_commit_log,          3},
+  {"R_git_commit_log",          (DL_FUNC) &R_git_commit_log,          4},
   {"R_git_config_list",         (DL_FUNC) &R_git_config_list,         1},
   {"R_git_config_set",          (DL_FUNC) &R_git_config_set,          3},
   {"R_git_conflict_list",       (DL_FUNC) &R_git_conflict_list,       1},
@@ -158,6 +162,15 @@ attribute_visible void R_init_gert(DllInfo *dll) {
   git_libgit2_init();
 #ifdef _WIN32
   const char *userprofile = getenv("USERPROFILE");
+  if(getenv("HOMEDRIVE") && getenv("HOMEPATH")){
+    char homedir[8000] = {0};
+    strcat(homedir, getenv("HOMEDRIVE"));
+    strcat(homedir, getenv("HOMEPATH"));
+    struct stat sb = {0};
+    if (stat(homedir, &sb) == 0 && S_ISDIR(sb.st_mode)){
+      userprofile = homedir;
+    }
+  }
   if(userprofile){
     /* Need to convert to UTF-8 for libgit2 */
     SEXP home = PROTECT(Rf_mkChar(userprofile));
